"""WebSearch API routes package."""

from .models import WebSearchRequest, WebSearchResultItem, WebSearchResponse

__all__ = [
    "WebSearchRequest",
    "WebSearchResultItem",
    "WebSearchResponse",
]